#
# spec file for package exo
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libexo-1-0
Name:           exo
Version:        0.10.6
Release:        3.35
Summary:        Application Development Library for Xfce
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Libraries
Url:            http://docs.xfce.org/xfce/exo/start
Source0:        http://archive.xfce.org/src/xfce/exo/0.10/%{name}-%{version}.tar.bz2
# icons taken from tango-icon-theme 0.8.90
Source1:        %{name}-icons.tar.bz2
# PATCH-FIX-OPENSUSE use-versioned-helpers-db.patch gber@opensuse.org -- Use a versioned helpers files DB since some of the desktop files are tied to the exo API version (e.g. by using exo-compose-mail-1)
Patch0:         use-versioned-helpers-db.patch
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  perl-URI
BuildRequires:  update-desktop-files
BuildRequires:  xfce4-dev-tools
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(libstartup-notification-1.0)
BuildRequires:  pkgconfig(libxfce4ui-1)
BuildRequires:  pkgconfig(libxfce4util-1.0)
# Prevent dependency cycle exo -> libxfce4ui-devel -> libxfce4ui-1-0 -> exo-tools
#!BuildIgnore:  exo-tools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Exo is an extension library to Xfce which is targeted at application
development.

%package tools
Summary:        Tools for exo
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Libraries
Provides:       exo:%{_bindir}/exo-csource
Provides:       exo:%{_bindir}/exo-desktop-item-edit
Provides:       exo:%{_bindir}/exo-open
Provides:       exo:%{_bindir}/exo-preferred-applications

%description tools
This package provides tools and helpers for exo.

%package -n %{libname}
Summary:        Application Development Library for Xfce
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Libraries
Requires:       %{libname}-branding = %{version}
Requires:       perl-URI
Recommends:     %{name}-lang = %{version}
Recommends:     %{name}-tools
Provides:       exo = %{version}
Obsoletes:      exo <= 0.6.2
Provides:       exo-doc = %{version}
Obsoletes:      exo-doc <= 0.6.2
Provides:       exo-data = %{version}
Obsoletes:      exo-data <= 0.10.2

%description -n %{libname}
Exo is an extension library to Xfce which is targeted at application
development.

%package devel
Summary:        Development Files for exo
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       %{name}-tools = %{version}

%description devel
This package contains development files needed for developing applications
based on exo.

%package -n %{libname}-branding-upstream
Summary:        Upstream Branding of exo
License:        GPL-2.0+
Group:          System/GUI/XFCE
Supplements:    packageand(%{libname}:branding-upstream)
# BRAND: helpers.rc: Controls default applications and MIME handler.
Conflicts:      otherproviders(%{libname}-branding)
Provides:       %{libname}-branding = %{version}
Provides:       exo-branding = %{version}
Provides:       exo-branding-upstream = %{version}
Obsoletes:      exo-branding-upstream <= 0.10.2
BuildArch:      noarch

%description -n %{libname}-branding-upstream
This package provides the upstream look and feel for the exo library.

# this should be replaced by %%lang_package once bnc#513786 is resolved
%package lang
Summary:        Languages for package %{name}
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Localization
Requires:       %{libname} = %{version}
Provides:       %{name}-lang-all = %{version}
Supplements:    packageand(bundle-lang-other:%{libname})
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%prep
%setup -q -b1
mkdir m4
%patch0 -p1
find . -name '*.pl' | \
    xargs sed -i 's|^#! */usr/bin/env *\perl|#!%{_bindir}/perl|'

%build
xdt-autogen
%configure \
  --docdir=%{_datadir}/xfce4/exo-preferred-applications \
  --with-helper-path-prefix=%{_libexecdir} \
  --enable-gtk-doc \
  --disable-static
make %{?_smp_mflags} V=1

%install
%make_install

# currently expected by too many Xfce packages
mkdir -p %{buildroot}%{_libdir}/xfce4

find %{buildroot} -type f -name "*.la" -delete -print

%if 0%{?suse_version} < 1220
# install icons
(
    cd ../exo-icons
    find usr -depth -print | cpio -pvd %{buildroot}
)
%endif

%fdupes %{buildroot}%{_datadir}

# remove unsupported locales
rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang exo-1 %{?no_lang_C}

%suse_update_desktop_file exo-preferred-applications
%suse_update_desktop_file exo-mail-reader
%suse_update_desktop_file exo-terminal-emulator
%suse_update_desktop_file exo-file-manager
%suse_update_desktop_file exo-web-browser

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%post tools
%icon_theme_cache_post
%desktop_database_post

%postun tools
%icon_theme_cache_postun
%desktop_database_postun

%files tools
%defattr(-,root,root)
%{_bindir}/exo-csource
%{_bindir}/exo-desktop-item-edit
%{_bindir}/exo-open
%{_bindir}/exo-preferred-applications
%{_datadir}/applications/exo-file-manager.desktop
%{_datadir}/applications/exo-mail-reader.desktop
%{_datadir}/applications/exo-preferred-applications.desktop
%{_datadir}/applications/exo-terminal-emulator.desktop
%{_datadir}/applications/exo-web-browser.desktop
%{_mandir}/man1/exo-csource.1*
%{_mandir}/man1/exo-open.1*
%{_datadir}/icons/hicolor/*/*/*

%files lang -f exo-1.lang
%defattr(-,root,root)

%files -n %{libname}
%defattr(-,root,root)
%doc README ChangeLog NEWS COPYING AUTHORS THANKS TODO
%{_libdir}/libexo-1.so.*
%dir %{_libdir}/xfce4
%dir %{_libexecdir}/xfce4
%dir %{_libexecdir}/xfce4/exo-1
# helper binaries which can be considered part of the API
%{_libexecdir}/xfce4/exo-1/exo-compose-mail-1
%{_libexecdir}/xfce4/exo-1/exo-helper-1
# the helper file db makes use of the above versioned binaries
%dir %{_datadir}/xfce4/exo-1
%{_datadir}/xfce4/exo-1/helpers
# frame image directly used by the library
%dir %{_datadir}/pixmaps/exo-1/
%{_datadir}/pixmaps/exo-1/exo-thumbnail-frame.png

%files devel
%defattr(-,root,root)
%{_includedir}/exo-1
%{_libdir}/libexo*.so
%{_libdir}/pkgconfig/exo*
%{_datadir}/gtk-doc/html/exo-1/

%files -n %{libname}-branding-upstream
%defattr(-,root,root)
%dir %{_sysconfdir}/xdg/xfce4
%dir %{_sysconfdir}/xdg/xfce4/exo-1
%config %{_sysconfdir}/xdg/xfce4/exo-1/helpers.rc

%changelog
* Mon May 25 2015 gber@opensuse.org
- update to version 0.10.6
  - Close fd with error state goto (CID 30797), extension of
    previous fix "File descriptor was never opened if < 0
    (CID #85387)"
* Mon May 25 2015 gber@opensuse.org
- update to version 0.10.5
  - Added --disable-debug to distcheck rules, this will allow
    building with autogen.sh --disable-debug on newer systems
    (bxo#11556)
  - Do not use x-scheme-handler/file mimetype (bxo#7257)
  - Escape URIs for exo-open (bxo#9912)
  - File descriptor was never opened if < 0 (CID #85387)
  - Reverted patches that broke window focus on startup
    (bxo#11743)
  - Fix StartupNotify (bxo#9570)
  - Fix implicit declaration of function 'xfce_spawn_on_screen'
    (bxo#11655)
  - Translation updates
* Tue Mar 17 2015 gber@opensuse.org
- update to version 0.10.4
  - don't quote arguments passed to terminal emulators (bxo#10731)
  - fix StartupNotify (bxo#9570)
  - fix implicit declaration of function 'xfce_spawn_on_screen'
    (bxo#11655)
  - translation updates
* Tue Mar 10 2015 gber@opensuse.org
- buildignore exo-tools in order to break the dependency cycle
  exo -> libxfce4ui-devel -> libxfce4ui-1-0 -> exo-tools
* Sat Feb 28 2015 gber@opensuse.org
- update to version 0.10.3
  - build updates and improvements (autotools, intltool)
  - increased required automake and libtool versions
  - updated mimeapps.list location for glib >= 2.41 (bxo#11504)
  - add an icon-column in the icon view for loading thumbnailed
    images
  - add helpers for qtFM, QTerminal, Qupzilla, Surf, Vimprobable2
    (bxo#10216)
  - add support for BCC in exo-compose-email (bxo#11070)
  - better handle filenames with spaces in exo-helpers (bxo#10731)
  - drop use of the -remote option in Firefox helpers (bxo#11601)
  - fix ATK deprecation warnings (bxo#11556)
  - fix exo_str_looks_like_an_uri() (bxo#10098)
  - fix small typo in exo-icon-bar (bxo#10515)
  - install category icons into proper location (bxo#11364)
  - scroll long file names into view in compact listview (bxo#6014)
  - translation updates
- drop obsolete exo-firefox-params.patch
* Sat Jan 25 2014 gber@opensuse.org
- fix a typo in use-versioned-helpers-db.patch causing custom
  preference files to be saved in the wrong location (bnc#860479)
* Thu May  2 2013 gber@opensuse.org
- also deliver helpers.rc into a API-versioned subdirectory, it is
  directly read by the library as well
- rename exo-branding-upstream to libexo-1-0-branding-upstream
- continue delivering %%{_libdir}/xfce4
* Thu May  2 2013 gber@opensuse.org
- add use-versioned-helpers-db.patch in order to use a versioned
  helpers files DB since some of the desktop files are tied to the
  exo API version (e.g. by using exo-compose-mail-1)
- consequently also merge exo-data into libexo-1-0
* Fri Dec 28 2012 gber@opensuse.org
- update to version 0.10.2
  - optimize returning the selected item in icon view
  - work with icon names in the toolbar editor
  - GIO unix is still used for exo-open
  - use same thumbnail frame as Thunar
  - rename Terminal to xfce4-terminal
  - remove unmaintained translations
  - add chromium-browser to binary names
  - add various helpers
* Mon Dec 17 2012 gber@opensuse.org
- update to version 0.10.1
  - bump glib to 2.30 and drop exo-gio-module
  - bump Gtk to 2.24
  - draw the rubberband identical to gtk
  - don't use GSimpleResult in ExoJob
  - fix shadowed variable
  - g_main_context_ref_thread_default() is 2.32 API
  - translation updates
* Mon Jul  2 2012 gber@opensuse.org
- do not package the internet-web-browser and internet-mail icons
  any more for >= 12.2 which are widely available and will be
  standardized
* Sun Apr 29 2012 gber@opensuse.org
- update to version 0.8.0
  - rename "Novell Evolution" to "Evolution"
  - add Iceweasel helper
  - translation updates
* Fri Apr 27 2012 gber@opensuse.org
- make the library package recommend exo-tools
* Thu Apr 19 2012 gber@opensuse.org
- properly obsolete exo-doc
* Sun Apr 15 2012 gber@opensuse.org
- removed system-file-manager and utilities-terminal icons since
  these are standard icon names from the Icon Naming Spec
* Sat Apr 14 2012 gber@opensuse.org
- update to version 0.7.3
  - enable startup-notify in the exo-open desktop files
  - use g_file_set_contents on local files
  - bump gtk to 2.20 and glib to 2.24
  - don't set invalid startup id
  - replace deprecated function g_strcasecmp
  - fix possible segfault in exo_str_looks_like_an_uri
  - updates licenses
  - fix saving of desktop files in local dir
  - translation updates
* Sun Apr  8 2012 gber@opensuse.org
- update to version 0.7.2
  - drop gtk 2.24 api
  - bump libxfce4ui dependency for help function
  - send exo-open startup-id to child instead of using it
  - add preferred app helper for Chromium
  - remove package manuals and link to online documentation
  - queue an icon view resize if the requesitions don't match
  - add new API exo_icon_view_get_item_{column,row}
  - add keynav-failed to ExoIconView
  - show Preferred Application in settings category
  - don't destroy already destroyed widget
  - do not insert symlink icons in the icon chooser
  - use libxfce4ui instead of support library
  - drop the python bindings
  - use new libtool macros and versions
  - remove spec file and rpm build
  - silenty save to local application is permission denied to
    original file in exo-desktop-item-edit
  - support hexadecimal xid and center exo-desktop-item-edit on
    parent
  - translation updates
* Sat Mar 31 2012 gber@opensuse.org
- fix provides
* Sun Mar 25 2012 gber@opensuse.org
- -branding-upstream should supplement exo-data
- replace %%lang_package by a manually specfified -lang package
- %%{libname} should recommend -lang since there are translations
  for the library
- drop rpmlintrc
* Mon Mar 19 2012 gber@opensuse.org
- split exo into libexo-1-0, exo-tools, and exo-data in order to
  conform to the shared library packaging policy
- added exo-icons.tar.bz2 with icons from tango-icon-theme 0.8.90
  in order to provide icons for all desktop files and to prevent a
  dependency on an icon theme
- specfile cleanup
- added exo-fix-python-install-location.patch in order to install
  all python files under %%%%{python_sitearch}
- dropped exo-env.patch, shebang lines are fixed during build
  instead
* Thu Oct 20 2011 gber@opensuse.org
- install HTML documentation under
  /usr/share/xfce4/exo-preferred-applications/html
* Fri Oct 14 2011 gber@opensuse.org
- recommend -doc subpackage
- move development documentation into development package
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
* Sat Jun 11 2011 gber@opensuse.org
- update to version 0.6.2:
  - improve exo-open url and email match regexes
  - allow installation of the helpers in a custom location
  - bugfixes
  - translation updates
- added patch tags
* Thu Feb 17 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Sun Jan 30 2011 gber@opensuse.org
- fix -devel package dependencies and description
* Sat Jan 29 2011 gber@opensuse.org
- added branding subpackage and removed
  exo-0.5.5-add-default-filemanager.patch as a corresponding
  helpers.rc is now delivered by openSUSE branding
* Mon Jan 17 2011 gber@opensuse.org
- update to version 0.6.0
  - bugfixes
* Sat Jan 15 2011 gber@opensuse.org
- do not require but recommend -lang subpackage
* Thu Jan  6 2011 gber@opensuse.org
- added exo-0.5.5-add-default-filemanager.patch in order to define
  Thunar as the default file manager
* Fri Dec 24 2010 gber@opensuse.org
- more appropriate category for the main package
* Thu Dec 23 2010 gber@opensuse.org
- improved summaries, descriptions
- marked config files
- split off python bindings into a separate package
- add missing dependency on python-gtk
- handle duplicate files in %%%%{python_sitearch}
- recompile python files instead of modifying them in place in
  order to prevent inconsistent mtime
- merged libexo-1-0 into exo since the library is not useful
  without its helper tools
- renamed rpmlintrc to exo-rpmlintrc according to packaging policy
* Fri Dec  3 2010 gber@opensuse.org
- removed GIO module from file list (suse >= 11.4)
* Fri Dec  3 2010 prusnak@opensuse.org
- updated to 0.5.5
  - Fix opening of URIs with spaces in claws-mail and sylpheed.
  - Fix two @libexecdir@ -> @HELPERDIR@ replacements.
  - Add Icedove helper.
  - Fix Opera helper with Opera >= 10.60.
  - Add mime types to the exo-open desktop files (bug #6800).
  - Store preferred application in mimeapps.list (bug #6800).
  - Don't build the GIO module after glib 2.27 (bug #6800).
  - Make exo-open more standalone (bug #6573).
  - Translation updates (ug, gl, zh_TW, ru, sk, ja, el, sv, es, eu,
    hu, pt, kk, it, ja, he, uk, ca, da, id).
* Thu Dec  2 2010 andrea@opensuse.org
- removed not needed BuildRequires
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Tue Nov 30 2010 andrea@opensuse.org
- update to 0.5.4
  - Abort dist if xml is not valid.
  - Fix exo-preffered-applications.
  - Move files from $libexecdir to $libdir.
  - Remove deprecated encoding key from desktop files.
  - Translations update
- Spec file clean up
* Sun Jul 18 2010 bernhard@bwalle.de
- updated to 0.3.107
  o Make the treeview work again with gtk 2.20 (bug #6230).
  o Fix compilation error (bug #6421).
  o Build ChangeLog from GIT.
  o Translation updates (pt, nl, it, am, bn, kk, ug, ru, ja).
* Wed Jan 13 2010 prusnak@suse.cz
- updated to 0.3.106
  - Only sync devices with no volume.
  - Updated translation: sk, nn.
- updated to 0.3.105
  - Read mount options from a rc file (bug #2891).
  - Version the API docs.
  - Fix notes when generating the man pages.
- updated to 0.3.104
  - Make unmount work for devices that have a parent that is a volume (bug #2968).
- updated to 0.3.103
  - Use the update-preview signal for updating the preview (bug #5133)
  - Add support for iocharset in exo-mount (bug #4294).
  - Make mounting NTFS drives work in exo-mount (bug #4532).
  - Open trash:// uris with the file manager (bug #5777).
  - Fix some small compiler warnings.
  - Switch the build files to use GIT.
  - Updated translation: ca (Carles Muñoz Gorriz)
- updated to 0.3.102
  - Allow all arguments in the terminal parameters (part of bug #5301).
  - Fix some issues in exo-open with spaces in arguments.
  - Properly handle NULL pixbufs in the toolbars code.
  - Make sure the ui-manager is up2date when creating the exo toolbar.
  - Fix possible segfault in exo_icon_view_get_item_at_pos (bug #5633).
  - Do not escape commas in urls (bug #5654).
  - Lookup the hardcoded paths for (u)mount during configure (bug #3717).
  - Fix missing include for strftime (bug #3751).
  - Prefer getvfsstat over getfsstat (bug #3718).
  - Don't abort if python is not found (bug #3751).
* Tue Aug 11 2009 puzel@novell.com
- revert new python macros on suse <= 11.1
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 0.3.101
* Fri Feb 27 2009 prusnak@suse.cz
- updated to 0.3.100 (Xfce 4.6.0 release)
- removed obsoleted hal.patch
* Mon Jan 26 2009 crrodriguez@suse.de
- remove the last "la" files that references "libhal*.la" (2/2)
  now hal can be cleaned up without breaking other packages
* Sun Jan 27 2008 coolo@suse.de
- fix changelog
* Wed Dec  5 2007 bwalle@suse.de
- updated exo-oldhal.patch (Fridrich Strba <fstrba@novell.com>)
* Mon Dec  3 2007 bwalle@suse.de
- update to exo 0.3.4
  o Add option to exo-csource to strip comments from XML prior to
    embedding them into binaries
  o Properly quote URLs prior to passing them to external programs
  o Bump required HAL version to 0.5.7
  o Updated translations
* Sun Oct 21 2007 bwalle@suse.de
- remove buildroot references from Python object files
* Sun Oct 21 2007 bwalle@suse.de
- build with HAL support for SLE10
- move preferred applications MCS plugin from exo-devel to exo
  (#325981)
- enable python extension
- replaced group 'System/GUI/Other' by 'System/GUI/XFCE'
* Tue Sep 18 2007 bwalle@suse.de
- move preferred applications MCS plugin from exo-devel to exo
  (#325981)
* Tue Jun 19 2007 prusnak@suse.cz
- cleaned spec file, moved some files to devel subpackage
* Wed Feb  7 2007 sbrabec@suse.cz
- Do not build static libraries (#238552).
* Fri Jan 26 2007 ro@suse.de
- added directory to filelist
* Sun Jan 21 2007 ro@suse.de
- minor fixes in filelist
* Sun Jan 21 2007 bwalle@suse.de
- upgrade to 0.3.2
- added HAL support on 10.2 and later
* Wed Jan 17 2007 pnemec@suse.cz
- package is merged from BuildService at version 0.3.1.12rc2
* Tue Dec 26 2006 bwalle@suse.de
- added patch in Mozilla desktop file that doesn't call mozilla openURL()
  because the Mozilla start script of SUSE already handles this -- current
  version doesn't handle the case where Mozilla is already running
  (applies also to Firefox)
* Sat Nov  4 2006 bwalle@suse.de
- updated to 4.3.99.2 (4.4 rc2)
* Mon Sep  4 2006 pnemec@suse.cz
- updated to new version 0.3.1.10rc1
* Wed Aug 23 2006 pnemec@suse.cz
- added dbus-devel to build requires
* Tue Aug  1 2006 pnemec@suse.cz
- initial comment, version is 0.3.1.8beta2
- package moved into BuildService
- no patch needed
